==> certmanager-model-v1alpha2-6.2.0-sources.jar: io/fabric8/certmanager/api/model/v1alpha2/CertificateRequestFluentImpl.java <==
package io.fabric8.certmanager.api.model.v1alpha2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class CertificateRequestFluentImpl<A extends CertificateRequestFluent<A>> extends BaseFluent<A> implements CertificateRequestFluent<A>{
  public CertificateRequestFluentImpl() {
  }
  public CertificateRequestFluentImpl(CertificateRequest instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private CertificateRequestSpecBuilder spec;
  private CertificateRequestStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public CertificateRequestFluent.MetadataNested<A> withNewMetadata() {
    return new CertificateRequestFluentImpl.MetadataNestedImpl();
  }
  public CertificateRequestFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new CertificateRequestFluentImpl.MetadataNestedImpl(item);
  }
  public CertificateRequestFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public CertificateRequestFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public CertificateRequestFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public CertificateRequestSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public CertificateRequestSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(CertificateRequestSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new CertificateRequestSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public CertificateRequestFluent.SpecNested<A> withNewSpec() {
    return new CertificateRequestFluentImpl.SpecNestedImpl();
  }
  public CertificateRequestFluent.SpecNested<A> withNewSpecLike(CertificateRequestSpec item) {
    return new CertificateRequestFluentImpl.SpecNestedImpl(item);
  }
  public CertificateRequestFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public CertificateRequestFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new CertificateRequestSpecBuilder().build());
  }
  public CertificateRequestFluent.SpecNested<A> editOrNewSpecLike(CertificateRequestSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public CertificateRequestStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public CertificateRequestStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(CertificateRequestStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new CertificateRequestStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public CertificateRequestFluent.StatusNested<A> withNewStatus() {
    return new CertificateRequestFluentImpl.StatusNestedImpl();
  }
  public CertificateRequestFluent.StatusNested<A> withNewStatusLike(CertificateRequestStatus item) {
    return new CertificateRequestFluentImpl.StatusNestedImpl(item);
  }
  public CertificateRequestFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public CertificateRequestFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new CertificateRequestStatusBuilder().build());
  }
  public CertificateRequestFluent.StatusNested<A> editOrNewStatusLike(CertificateRequestStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    CertificateRequestFluentImpl that = (CertificateRequestFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<CertificateRequestFluent.MetadataNested<N>> implements CertificateRequestFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) CertificateRequestFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends CertificateRequestSpecFluentImpl<CertificateRequestFluent.SpecNested<N>> implements CertificateRequestFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(CertificateRequestSpec item) {
      this.builder = new CertificateRequestSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new CertificateRequestSpecBuilder(this);
    }
    CertificateRequestSpecBuilder builder;
    public N and() {
      return (N) CertificateRequestFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends CertificateRequestStatusFluentImpl<CertificateRequestFluent.StatusNested<N>> implements CertificateRequestFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(CertificateRequestStatus item) {
      this.builder = new CertificateRequestStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new CertificateRequestStatusBuilder(this);
    }
    CertificateRequestStatusBuilder builder;
    public N and() {
      return (N) CertificateRequestFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> certmanager-model-v1alpha2-6.7.1-sources.jar: io/fabric8/certmanager/api/model/v1alpha2/CertificateRequestFluentImpl.java <==
package io.fabric8.certmanager.api.model.v1alpha2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class CertificateRequestFluentImpl<A extends CertificateRequestFluent<A>> extends BaseFluent<A> implements CertificateRequestFluent<A>{
  public CertificateRequestFluentImpl() {
  }
  public CertificateRequestFluentImpl(CertificateRequest instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private CertificateRequestSpecBuilder spec;
  private CertificateRequestStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public CertificateRequestFluentImpl.MetadataNested<A> withNewMetadata() {
    return new CertificateRequestFluentImpl.MetadataNestedImpl();
  }
  public CertificateRequestFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new CertificateRequestFluentImpl.MetadataNestedImpl(item);
  }
  public CertificateRequestFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public CertificateRequestFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public CertificateRequestFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public CertificateRequestSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public CertificateRequestSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(CertificateRequestSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new CertificateRequestSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public CertificateRequestFluentImpl.SpecNested<A> withNewSpec() {
    return new CertificateRequestFluentImpl.SpecNestedImpl();
  }
  public CertificateRequestFluentImpl.SpecNested<A> withNewSpecLike(CertificateRequestSpec item) {
    return new CertificateRequestFluentImpl.SpecNestedImpl(item);
  }
  public CertificateRequestFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public CertificateRequestFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new CertificateRequestSpecBuilder().build());
  }
  public CertificateRequestFluentImpl.SpecNested<A> editOrNewSpecLike(CertificateRequestSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public CertificateRequestStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public CertificateRequestStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(CertificateRequestStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new CertificateRequestStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public CertificateRequestFluentImpl.StatusNested<A> withNewStatus() {
    return new CertificateRequestFluentImpl.StatusNestedImpl();
  }
  public CertificateRequestFluentImpl.StatusNested<A> withNewStatusLike(CertificateRequestStatus item) {
    return new CertificateRequestFluentImpl.StatusNestedImpl(item);
  }
  public CertificateRequestFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public CertificateRequestFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new CertificateRequestStatusBuilder().build());
  }
  public CertificateRequestFluentImpl.StatusNested<A> editOrNewStatusLike(CertificateRequestStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CertificateRequestFluentImpl that = (CertificateRequestFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<CertificateRequestFluentImpl.MetadataNested<N>> implements CertificateRequestFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) CertificateRequestFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends CertificateRequestSpecFluentImpl<CertificateRequestFluentImpl.SpecNested<N>> implements CertificateRequestFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(CertificateRequestSpec item) {
      this.builder = new CertificateRequestSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new CertificateRequestSpecBuilder(this);
    }
    CertificateRequestSpecBuilder builder;
    public N and() {
      return (N) CertificateRequestFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends CertificateRequestStatusFluentImpl<CertificateRequestFluentImpl.StatusNested<N>> implements CertificateRequestFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(CertificateRequestStatus item) {
      this.builder = new CertificateRequestStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new CertificateRequestStatusBuilder(this);
    }
    CertificateRequestStatusBuilder builder;
    public N and() {
      return (N) CertificateRequestFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
